@@ -779,7 +779,7 @@ declare_choice!(Choice3 => (T1 ChoiceA), (T2 ChoiceB), (T3 ChoiceC));
 /// Represents an ASN.1 `SEQUENCE`. By itself, this merely indicates a sequence of bytes that are
 /// claimed to form an ASN1 sequence. In almost any circumstance, you'll want to immediately call
 /// `Sequence.parse` on this value to decode the actual contents therein.
-#[derive(Debug, PartialEq, Hash)]
+#[derive(Debug, PartialEq, Hash, Clone)]
 pub struct Sequence<'a> {
     data: &'a [u8],
 }
@@ -944,7 +944,7 @@ impl<'a, T: Asn1Readable<'a> + Asn1Writable<'a>> SimpleAsn1Writable<'a> for Sequ
 }
 
 /// Writes a `SEQUENCE OF` ASN.1 structure from a slice of `T`.
-#[derive(Hash, PartialEq)]
+#[derive(Hash, PartialEq, Clone)]
 pub struct SequenceOfWriter<'a, T: Asn1Writable<'a>, V: Borrow<[T]> = &'a [T]> {
     vals: V,
     _phantom: PhantomData<&'a T>,
@@ -1081,7 +1081,7 @@ impl<'a, T: Asn1Readable<'a> + Asn1Writable<'a>> SimpleAsn1Writable<'a> for SetO
 
 /// Writes an ASN.1 `SET OF` whose contents is a slice of `T`. This type handles
 /// ensuring that the values are properly ordered when written as DER.
-#[derive(Hash, PartialEq)]
+#[derive(Hash, PartialEq, Clone)]
 pub struct SetOfWriter<'a, T: Asn1Writable<'a>, V: Borrow<[T]> = &'a [T]> {
     vals: V,
     _phantom: PhantomData<&'a T>,
